@@ -1,7 +1,8 @@
-from datetime import datetime, tzinfo
 import pytz
 import json
 import time
+import ssl
+
 from omnik.ha_logger import hybridlogger
 
 import paho.mqtt.client as mqttclient
@@ -40,6 +41,12 @@ class mqtt(Plugin):
         )
         self.mqtt_host = self.config.get("output.mqtt", "host", fallback="localhost")
         self.mqtt_port = int(self.config.get("output.mqtt", "port", fallback="1833"))
+
+        self.tls = self.config.getboolean("output.mqtt", "tls", fallback=False)
+        self.ca_certs = self.config.get("output.mqtt", "ca_certs", fallback=None)
+        self.client_cert = self.config.get("output.mqtt", "client_cert", fallback=None)
+        self.client_key = self.config.get("output.mqtt", "client_key", fallback=None)
+
         self.mqtt_retain = self.config.getboolean(
             "output.mqtt", "retain", fallback=False
         )
@@ -69,6 +76,13 @@ class mqtt(Plugin):
         self.mqtt_client.hass_api = self.hass_api
         # self.mqtt_client.on_message=mqtt_on_message (not used)
         self.mqtt_client.username_pw_set(self.mqtt_username, self.mqtt_password)
+        # TLS support
+        if self.tls:
+            self.mqtt_client.tls_set(
+                ca_certs=self.ca_certs or None,
+                certfile=self.client_cert or None,
+                keyfile=self.client_key or None,
+            )
         if self.config.has_option("output.mqtt", "discovery_prefix"):
             self.discovery_prefix = self.config.get("output.mqtt", "discovery_prefix")
         else:
@@ -138,11 +152,16 @@ class mqtt(Plugin):
         topic_suffix = f"_{msg['plant_id']}" if not msg["plant_id"] == "0" else ""
         topics = {}
         for asset_class in asset_classes:
+            device_name = self.config.attributes["devicename"][
+                self.config.attributes["device_identifier"][asset_class]
+            ]
             topics[asset_class] = {}
             topics[asset_class][
                 "main"
-            ] = f"{self.discovery_prefix}/sensor/{self.config.attributes['devicename'][asset_class]}{topic_suffix}"
-            topics[asset_class]["state"] = f"{topics[asset_class]['main']}/state"
+            ] = f"{self.discovery_prefix}/sensor/{device_name}{topic_suffix}"
+            topics[asset_class][
+                "state"
+            ] = f"{topics[asset_class]['main']}/{asset_class}_state"
             topics[asset_class]["attr"] = f"{topics[asset_class]['main']}/attr"
             topics[asset_class]["config"] = {}
             for field in self.config.data_field_config:
@@ -157,7 +176,9 @@ class mqtt(Plugin):
         for asset_class in asset_classes:
             device_pl[asset_class] = {}
             # Set device_name
-            device_name = self.config.attributes["devicename"][asset_class]
+            device_name = self.config.attributes["devicename"][
+                self.config.attributes["device_identifier"][asset_class]
+            ]
             # Determine appendixes
             name_appendix = ""
             identifier = self.config.attributes["identifier"][asset_class]
@@ -170,7 +191,9 @@ class mqtt(Plugin):
                 id_prefix = f"{msg[identifier]}_"
             # Device payload
             device_pl[asset_class] = {
-                "identifiers": [f"{id_prefix}{asset_class}"],
+                "identifiers": [
+                    f"{id_prefix}{self.config.attributes['device_identifier'][asset_class]}"
+                ],
                 "name": f"{device_name}{name_appendix}",
                 "mdl": self.config.attributes["model"][asset_class],
                 "mf": self.config.attributes["mf"][asset_class],
@@ -206,7 +229,7 @@ class mqtt(Plugin):
                 "~": f"{topics[asset_class]['main']}",
                 "uniq_id": f"{msg[identifier]}_{field}",
                 "name": f"{fieldname}",
-                "stat_t": "~/state",
+                "stat_t": f"~/{asset_class}_state",
                 "json_attr_t": "~/attr",
                 "val_tpl": f"{{{{(value_json.{field}{self.config.data_field_config[field]['filter']})}}}}",
                 "dev": device_pl[asset_class],
